function h = Fit_1G0(G,Parameters,Histograms,Files)

fitmin = 0.5;
fitmax = 1.5;
scalefactor = 0.5; 
g0teo = 0.25;
slopemin = -0.5;
slopemax = 0.2;
smin = -inf; %aprox slope tunneling

hist1D=Histograms(1).histo1D;

   
    %% ALFREDO - Modified by Luca
    ytemp1 = find(Parameters.yedges>fitmin,1,'first');
    ytemp2 = find(Parameters.yedges>fitmax,1,'first');
    histx = Parameters.yedges(ytemp1:ytemp2);
    histy = hist1D(ytemp1:ytemp2);
    f = fit(histx',histy,'gauss1');
    valmax = f.b1+scalefactor*sqrt(f.c1); %scalefactor of 0.5 means it is taking + (-) the variance from the fit centre (see matlab definition of Gauss function)
    valmin = f.b1-scalefactor*sqrt(f.c1);
    
    figure
    plot(f,histx,histy,'b')
    hold on
    line([valmax valmax],get(gca,'YLim'),'Color',[0 1 0])
    line([valmin valmin],get(gca,'YLim'),'Color',[0 1 0])
    title('1D histogram 1G0')
    figure_title = '1G_0 length';
    
    G0Length = zeros(1,Files.Nplotted);
    G0Slope = zeros(1,Files.Nplotted);
    G0_reject = zeros(1,Files.Nplotted);
        parfor i = Files.plotstart:Files.plotend
            try
                xstart = find((G(i).g_breaking)<valmax,1,'first');   % 10^0.15 = 1.4125
                xend = find((G(i).g_breaking)>valmin,1,'last'); 
                
                if isempty(xstart) || isempty(xend) || isnan(xstart) || isnan(xend)
                    G0_reject(i) = i;
                    G0Length(i) = NaN;  
                    G0Slope(i) = NaN; 
                elseif xstart < xend
                    G0fit = fit(G(i).d_breaking(xstart:xend),G(i).g_breaking(xstart:xend),'poly1');
                    G0Slope(i)= G0fit.p1;
                    if G0fit.p1 < slopemin || G0fit.p1 > slopemax
                        G0_reject(i) = i;
                        G0Length(i) = NaN;
                        G0Slope(i) = NaN; 
                    else
                        G0Length(i) = G(i).d_breaking(xend)-G(i).d_breaking(xstart);
                    end
                        
                else
                    G0_reject(i) = i;
                    G0Length(i) = NaN;
                    G0Slope(i) = NaN; 
                end
                
            catch err
                if G(i).g_breaking(1) == Parameters.noiselvl
                    G0_reject(i) = i;
                    %idx = idx+1;
                    G0Length(i) = NaN;
                else
                    disp (i)
                    disp(err)
                end
                
            end
        end
    G0_reject = G0_reject(G0_reject>0);
    nbins = floor(Parameters.Xbin/4);
    h = figure('Position',[300 150 1100 775],'PaperPositionMode','auto');
    hfit = histfit(G0Length,nbins,'kernel');
    hold on
    meanfit = hfit(2).XData(hfit(2).YData ==max(hfit(2).YData));
    line([g0teo g0teo], get(gca,'YLim'),'Linestyle','--','LineWidth',2,'Color','k'); % 4.5eV
    title(figure_title)
    ylabel('Counts / trace');
    xlabel('Length [nm]');
    set(gca,'Xlim',[0 1])
    set(gca,'fontsize',20,'fontweight','normal')
    set(findall(gcf,'type','text'),'fontsize',20,'fontweight','normal')
    set(gca,'linewidth',2,'box','on')
    set(gcf,'color','white')
    set(gca,'Tickdir','in')
    legend('Plateau length',['Kernel fit - max = ',num2str(meanfit)] ,'Theoretical value')
    
% catch
% %     %% ORIGINAL
%     disp('First method for 1G0 fitting aborted')
%     G0Length = zeros(1,Files.Nplotted);
%     h = figure('Position',[300 150 1100 775],'PaperPositionMode','auto');
%     for i = Files.plotstart:Files.plotend
%         try
%             xstart = find((G(i).g_breaking)<2.10^0,1,'first');   %10^0.2305  10^0.15 = 1.4125
%             xend = find((G(i).g_breaking)>8.10^-1 ,1,'last');     % 3e-1 10^-0.15 = 0.7079 it is different than previously defined (3e-1) but makes effectively no difference
%             G0Length(i) = (G(i).d_breaking(xend)-G(i).d_breaking(xstart));
%         catch err
%             disp(err)
%         end
%     end
%     G0Length = G0Length(G0Length~=0);
% 	 G0Lengthbins = -0.0:(Parameters.Xmax-Parameters.Xmin)/Parameters.Xbin:2;
% 	 G0Lengthhisto = hist(G0Length,G0Lengthbins);
%     G0Lengthhisto = G0Lengthhisto/Files.Nplotted;
% 
%     signal=[G0Lengthbins' G0Lengthhisto'];
%     guess=[0.25,0.1];
%     [FitResults, ~, ~] = peakfit(signal,0,0,1,1,0,3,guess,0,0,0);
% 
%     Peakshape=1;
%     bar(G0Lengthbins,G0Lengthhisto);
%     title('G_0 length')
%     ylabel('Counts / trace');
%     xlabel('Length [nm]');
%     set(gca,'Xlim',[0 1])
%     set(gca,'Ylim',[0 1.05*max(G0Lengthhisto)])
%     set(gca,'fontsize',20,'fontweight','normal')
%     set(findall(gcf,'type','text'),'fontsize',20,'fontweight','normal')
%     set(gca,'linewidth',2,'box','on')
%     set(gcf,'color','white')
%     set(gca,'Tickdir','in')
%     hold on
% 
%     if Peakshape == 1
%         g=@(x,par)par(3)*exp(-((x-par(2))./(0.6005615.*par(4))) .^2);%gaussian
%      elseif Peakshape == 2
%         g=@(yplot,par) par(3)./(1+((yplot-par(2))./(0.5.*par(4))).^2);%lorenzian
%      else
%         disp('Peak shape not recognized');
%     end
% 
%     yplotfit=linspace(0,5,500);
%     plot(yplotfit,g(yplotfit,FitResults(:)),'--r','linewidth',2.0)
%     str1=sprintf('%0.2f',FitResults(2));
%     str2='$$\pm$$';
%     str3=sprintf('%0.2f nm',FitResults(4)/(2*sqrt(2*log(2))));
%     str=strcat(str1,str2,str3);
%     legend({'Plateau length', str},'Interpreter','latex')
% end

end
