function h = Fit_Tunn(G, method)

if nargin<2
    method = 0; %0: fit / 1: diff
end
SlopeMeans = zeros(1,length(G));
diff_limit = 1.5;
tun_min = log10(2e-6);
tun_max = log10(1e-3);

for i=1:length(G)
    %Log scale
    glog = log10(G(i).g_breaking);
    dlog = G(i).d_breaking;
    
    dlog(glog<=-7.5) = [];
    glog(glog<=-7.5) = [];  

    %Index tunneling
    index2 = find(glog<tun_min,1,'first');
    index1 = find(glog>=tun_max,1,'last');

    g_tun = glog(index1:index2);
    d_tun = dlog(index1:index2);
     
    if method ==1
        %Diff
        g_dif = diff(g_tun);
        d_dif = diff(d_tun);
        %Remove outsiders
        g_filt = g_dif;
        g_filt(abs(g_dif)>diff_limit) = [];
        d_filt = d_dif;
        d_filt(abs(g_dif)>diff_limit) = [];
        %Assign variable
        SlopeMeans(i) = mean(g_filt./d_filt);
        
    elseif method ==0
        %Linear fit method
        P = polyfit(d_tun,g_tun,1);
        %Assign variable
        SlopeMeans(i) = P(1);
    end
end

%% Theoretical slopes
phi45 = -9.4333; %W.F. of 4.5eV
phi55 = -10.4289; %W.F. of 5.5eV

%% Plots
h = figure('Position',[300 150 1100 775],'PaperPositionMode','auto');
nbins = 200;
hfit = histfit(SlopeMeans,nbins,'kernel');
meanfit = hfit(2).XData(hfit(2).YData ==max(hfit(2).YData));
hold on

if method==0
    title('Tunneling slope (log scale) - fit method')
else
    title('Tunneling slope (log scale) - diff method')
end
ylabel('Counts / trace');
xlabel('Slope [dec/nm]');
set(gca,'Xlim',[-30 20])
set(gca,'fontsize',20,'fontweight','normal')
set(findall(gcf,'type','text'),'fontsize',20,'fontweight','normal')
set(gca,'linewidth',2,'box','on')
line([phi45 phi45], get(gca,'YLim'),'Linestyle','--','LineWidth',2,'Color','k'); % 4.5eV
line([phi55 phi55], get(gca,'YLim'),'Linestyle',':','LineWidth',2,'Color','k'); % 5.5eV
legend('Slope histogram',['Kernel fit - max = ',num2str(meanfit)] ,'\Phi = 4.5 eV','\Phi = 5.5 eV')
set(gcf,'color','white')
set(gca,'Tickdir','in')
end