function Plateau_info = Get_Info(G,Kmeans,Histograms,Parameters,Files,Fits,L_Fits)

Plateau_info = struct('yield',{},'length',{},'position',{},'g_value',{},'FWHM',{},'std',{},'position_leg',{},'length_leg',{},'Length_fit',{},'Length_std',{},'name',{});

for i=1:length(Fits)
    % Yield - First is raw data, then classes and then merged
    if i==1
        Plateau_info(1).yield = 100;
        Plateau_info(1).name = Histograms(1).name;
    elseif isstruct(Kmeans) && i<=length(Kmeans)+1
        Plateau_info(i).yield = 100*length(Kmeans(i-1).g_breaking)/Files.Nplotted;
        Plateau_info(i).name = Histograms(i).name;
    else
        Plateau_info(i).yield = NaN;    %Not defined because I'm lazy <- Good Boy
    end
    if Fits(i).result~=0
        for j=1:length(Fits(i).line)
            if j>1 && j==length(Fits(i).line)
                break
            end
            %G mean
            Plateau_info(i).g_value(j) = 10.^Fits(i).result(j,2);
            
            %std
            Plateau_info(i).std(j) = Fits(i).result(j,4);
            
            %FWHM for REAL histogram (not fit)
            try
                tmp = Histograms(i).histo1D;
                temp = find(Fits(i).line{j}==max(Fits(i).line{j}));
                tmp1 = tmp(temp:end);
                tmp2 = fliplr(tmp(1:temp));
                tmp_a = log10(Parameters.yedges(temp+find(tmp1<tmp1(1)/2,1,'first')));
                tmp_b = log10(Parameters.yedges(temp-find(tmp2<tmp2(1)/2,1,'first')));
                tmp = (abs(tmp_a*2-Plateau_info(i).std(j))<=abs(tmp_b*2-Plateau_info(i).std(j)));
                if isempty(tmp_a) && isempty(tmp_b)
                    disp('FWHM not clear, assigning std instead')
                    Plateau_info(i).FWHM(j) = Plateau_info(i).std(j);
                elseif isempty(tmp_a)
                    Plateau_info(i).FWHM(j) = 2*abs(log10(Plateau_info(i).g_value(j))-tmp_b); 
                elseif isempty(tmp_b)
                    Plateau_info(i).FWHM(j) = 2*abs(log10(Plateau_info(i).g_value(j))-tmp_a); 
                else
                    Plateau_info(i).FWHM(j) = 2*abs(log10(Plateau_info(i).g_value(j)) - tmp_a*tmp + tmp_b*2*not(tmp));
                end
            catch
                disp('FWHM not clear, assigning std instead')
                Plateau_info(i).FWHM(j) = Plateau_info(i).std(j);
            end
            
            %Length (based in std not in FWHM)
            Lmean = [];
            Lposition = [];
            Lmean_leg = [];
            Lposition_leg = [];
            tmp2 = 10^(log10(Plateau_info(i).g_value(j))-1.5*Plateau_info(i).std(j));
            tmp1 = 10^(log10(Plateau_info(i).g_value(j))+1.5*Plateau_info(i).std(j));
            if tmp2 < Parameters.Gmin %if the boundary is at noise level, sets the min conductace as boundary
                tmp2 = Parameters.Gmin;
            end
            
            if i==1
                for k=1:length(G)
                    try
                        l1 = G(k).d_breaking(G(k).g_breaking>tmp1);
                        l2 = G(k).d_breaking(G(k).g_breaking<tmp2);
                        if ~isempty(l1) && ~isempty(l2) && l2(1)>l1(end)
                            Lmean(k) = l2(1)-l1(end);
                            Lposition(k) = (l2(1)+l1(end))/2;
                        end
                    catch
                        Lmean(k) = NaN;
                        Lposition(k) = NaN;
                    end
                        %Legacy for calculation to match the Kmeans python
                        %script
                    try
                        window_width = 1;
                        tmp4 = 10^(log10(Plateau_info(i).g_value(j))-window_width/2);
                        tmp3 = 10^(log10(Plateau_info(i).g_value(j))+window_width/2);
                        l3 = tmp(Kmeans(i-1).g_breaking{k}>tmp3);
                        l4 = tmp(Kmeans(i-1).g_breaking{k}<tmp4);
                        if l4(1)>l3(end)
                            Lmean_leg(k) = l4(1)-l3(end);
                            Lposition_leg(k) = (l4(1)+l3(end))/2;
                        end 
                    catch                        
                        Lmean_leg(k) = NaN;
                        Lposition_leg(k) = NaN;
                    end
                end
            elseif isstruct(Kmeans) && i<length(Kmeans)+2
                for k=1:length(Kmeans(i-1).g_breaking)
                    try
                        tmp = Kmeans(i-1).d_breaking{k};
                        l1 = tmp(Kmeans(i-1).g_breaking{k}>tmp1);
                        l2 = tmp(Kmeans(i-1).g_breaking{k}<tmp2);
                        if l2(1)>l1(end)
                            Lmean(k) = l2(1)-l1(end);
                            Lposition(k) = (l2(1)+l1(end))/2;
                        end
                    catch
                        Lmean(k) = NaN;
                        Lposition(k) = NaN;
                    end
                    
                    try
                        %Legacy for calculation to match the Kmeans python
                        %script
                        window_width = 1;
                        tmp4 = 10^(log10(Plateau_info(i).g_value(j))-window_width/2);
                        tmp3 = 10^(log10(Plateau_info(i).g_value(j))+window_width/2);
                        l3 = tmp(Kmeans(i-1).g_breaking{k}>tmp3);
                        l4 = tmp(Kmeans(i-1).g_breaking{k}<tmp4);
                        if l4(1)>l3(end)
                            Lmean_leg(k) = l4(1)-l3(end);
                            Lposition_leg(k) = (l4(1)+l3(end))/2;
                        end

                    catch
                        Lmean_leg(k) = NaN;
                        Lposition_leg(k) = NaN;
                    end
                end
            else
                Lmean = 0;  %Not defined because I'm lazy!
            end
            Lmean = Lmean(Lmean>0.05); % the condition > 0.05 is chosen to exclude those traces which have an overshoot, which is often taken as an extreme, and messes up the length
            Lposition = Lposition(Lposition>0.05);
            Lmean_leg = Lmean_leg(Lmean_leg>0.05);
            Lposition_leg = Lposition_leg(Lposition_leg>0.05);
            
            Plateau_info(i).length(j) = mean(Lmean);
            Plateau_info(i).position(j) = mean(Lposition);
            Plateau_info(i).length_leg(j) = mean(Lmean_leg);
            Plateau_info(i).position_leg(j) = mean(Lposition_leg);
            
        end
        
    end

    if L_Fits(i).result ~=0
        for j=1:length(L_Fits(i).line)
            if j>1 && j==length(L_Fits(i).line)
                break
            end
            %L mean
            Plateau_info(i).Length_fit(j) = Parameters.Ledges(L_Fits(i).line{j}==max(L_Fits(i).line{j}));
            
            %std
            Plateau_info(i).Length_std(j) = L_Fits(i).result(j,4);
        end
    end
    
end

end