function [G,Histograms,Kmeans,Parameters] = HistoFunction(G,Kmeans,Parameters,Files,Bools)
%% Parameters
ZeroDisp = 3e-1;
Parameters.Xbin = round((Parameters.Xmax-Parameters.Xmin)*Parameters.binsperX);
Parameters.Ybin = round((Parameters.Ymax-Parameters.Ymin)*Parameters.binsperY);
Parameters.xedges = linspace(Parameters.Xmin,Parameters.Xmax,Parameters.Xbin);
Parameters.yedges = 10.^linspace(Parameters.Ymin,Parameters.Ymax,Parameters.Ybin);
Parameters.Ledges = linspace(0,Parameters.Lmax,Parameters.Lbin);
hist2D = zeros(Parameters.Ybin,Parameters.Xbin);

if isstruct(Kmeans)
    try
        Khist2D = cell(1,length(Kmeans)+length(Parameters.merged));
        Khist1D = cell(1,length(Kmeans)+length(Parameters.merged));
        KhistL  = cell(1,length(Kmeans)+length(Parameters.merged));
    catch
        Khist2D = cell(1,length(Kmeans));
        Khist1D = cell(1,length(Kmeans)); 
        KhistL = cell(1,length(Kmeans));
        KLbins = cell(1,length(Kmeans));
    end
end
    
disp(['Histograms include traces from ' num2str(Files.plotstart) ' to ' num2str(Files.plotend)])

Histograms = struct('histo1Dsingle',{},'histo1D',{},'histo2D',{},'histoL',{},'histo2DCC',{},'name',{});

%% Allignement
Parameters.purge_count=[];
index=1;
for i = 1:Files.Nfiles
      try
        ind = find(G(i).g_breaking>ZeroDisp,1,'last');
        d0 = G(i).d_breaking(max(ind));
        G(i).d_breaking = G(i).d_breaking-d0;
      catch
          if G(i).g_breaking(1) == Parameters.noiselvl
              %disp([num2str(i) ' - trace purged'])
              Parameters.purge_count(index)=i;
              index = index+1;
          else
              disp([num2str(i) ' - error finding first point'])
          end
      end
end
clear index
disp([num2str(length(Parameters.purge_count)) ' - trace purged'])

if isstruct(Kmeans)
    for j = 1:length(Kmeans)
      for i=1:length(Kmeans(j).d_breaking)
          try
            tmp = Kmeans(j).g_breaking{i};
            ind = find(tmp>ZeroDisp,1,'last');
            tmp = Kmeans(j).d_breaking{i};
            d0 = tmp(max(ind));
            Kmeans(j).d_breaking{i} = Kmeans(j).d_breaking{i}-d0;
          catch
              if Kmeans(j).g_breaking{i}(1) == Parameters.noiselvl
                  disp([num2str(i) ' - trace purged'])
              else disp([num2str(i) ' - error finding first point'])
              end
          end
      end
    end
end

%% Create 1D and 2D histogram
Ltemp = zeros(1,length(Files.plotstart:Files.plotend));
single_hist1D = zeros(length(Files.plotstart:Files.plotend),length(Parameters.yedges));

for i = Files.plotstart:Files.plotend
    tmp = hist2(G(i).d_breaking,G(i).g_breaking, Parameters.xedges, Parameters.yedges);
    hist2D = hist2D + tmp;
    single_hist1D(i,:) = sum(tmp,2);
    Ltemp(i) = length_calc(G(i).d_breaking,G(i).g_breaking,Parameters);
end

hist1D = sum(hist2D,2);
%[histL,Lbin] = histcounts(Ltemp,'binmethod','fd');
histL= hist(Ltemp,Parameters.Ledges);

if isstruct(Kmeans)
    try
        tmp = Parameters.merged;
        for i=1:length(tmp) %for each merged class, add a "column" to Kmeans dedicated to that merging
           Khist2D{length(Kmeans)+i} = zeros(Parameters.Ybin,Parameters.Xbin);
           KhistL{length(Kmeans)+i}  = zeros(1,Parameters.Lbin);
           Khist1Dsingle{length(Kmeans)+i} = zeros(length(Files.plotstart:Files.plotend),length(Parameters.yedges));
        end
    catch
        tmp = NaN;
    end
    Length=cell([length(Kmeans) 1]);
    for j = 1:length(Kmeans)
        mergedbool = 0; %if 1 Kmeans(j) is added to the specified merged class
        Khist2D{j} = zeros(Parameters.Ybin,Parameters.Xbin);
        if iscell(tmp)
            for i=1:length(tmp)
                c = tmp{i};
                if length(Kmeans(j).class)<9 && ~isempty(find(cell2mat(c)==-1,1)) %Only one -1, the first
                    for k=1:length(c)
                        temp = c{k};
                        if temp(1)==-1 && ismember(str2double(Kmeans(j).class(find(Kmeans(j).class==' '):end))-1,temp(2:end)) %if the current merging array uses classes (starts with -1) and the current class Kmeans(j) is in the merging array
                            mergedbool=1; 
                            mindex = length(Kmeans)+i; %index to tell that this class should be added to the ith merged class
                            break
                        end
                    end
                    if mergedbool
                        break
                    end
                elseif length(Kmeans(j).class)>9
                    for k=1:length(c)
                        temp = c{k};
                        temp2 = find(Kmeans(j).class==' '); %guess this has to do on how you name subclasses
                        if str2double(Kmeans(j).class(temp2(1):temp2(2)))-1==temp(1) && ismember(str2double(Kmeans(j).class(temp2(3):end))-1,temp(2:end)) %if the (sub)class Kmeans(j) is in the merging array {temp2(1):temp2(2) for class number, str2double(Kmeans(j).class(temp2(3):end) for subclass number}
                            mergedbool=1;
                            mindex = length(Kmeans)+i;
                            break
                        end
                    end
                    if mergedbool
                        break
                    end
                end
            end
        end
        for i=1:length(Kmeans(j).d_breaking)
            htmp = hist2(Kmeans(j).d_breaking{i},Kmeans(j).g_breaking{i}, Parameters.xedges, Parameters.yedges);
            Khist2D{j} = Khist2D{j} + htmp;
            Khist1Dsingle{j}(i,:) = sum(htmp,2);
            if ~isempty(Kmeans(j).d_breaking{i}) %skip purged traces
                Length{j}(i) = length_calc(Kmeans(j).d_breaking{i},Kmeans(j).g_breaking{i},Parameters);
            end
            if mergedbool
                Khist2D{mindex} = Khist2D{mindex} + htmp;
                KhistL{mindex} = KhistL{mindex} + hist(Length{j}(i),Parameters.Ledges);
                Khist1Dsingle{mindex}(i,:) = sum(htmp,2);
            end
        end
        Khist1D{j} = sum(Khist2D{j},2);
        KhistL{j} = hist(Length{j},Parameters.Ledges);
        %[KhistL{j},KLbins{j}] = histcounts(Length{j},'binmethod','fd');
        if mergedbool
            Khist1D{mindex} = sum(Khist2D{mindex},2);
        end
    end
end

%% Normalization
hist1D = hist1D/Files.Nplotted;
hist2D = hist2D/Files.Nplotted;
%histL  = histL/Files.Nplotted; %No normalization, does not make sense to
%speak about trace length per trace

if isstruct(Kmeans)
    for i=1:length(Khist2D)
        N=Files.Nplotted;              %to normalize each cluster with respect to the total N of traces
        %N=length(Kmeans(i).d_breaking); %to normalize each cluster with respect to his own size
        Khist2D{i} = Khist2D{i}/N;
        Khist1D{i} = Khist1D{i}/N;
        %KhistL{i}  = KhistL{i}/N;
    end
end

%% 2D cross-covariance histograms

hist2DCC = corrcoef(single_hist1D);

if isstruct(Kmeans)
    for i=1:length(Khist2D)
        Khist2DCC{i} = corrcoef (Khist1Dsingle{i});
    end
end


%% Assign
Histograms(1).histo1D = hist1D;
Histograms(1).histo2D = hist2D;
Histograms(1).histoL  = histL;
Histograms(1).histo1Dsingle = single_hist1D;
%Histograms(1).Lbin  = Lbin;
Histograms(1).histo2DCC = hist2DCC;
Histograms(1).name = 'raw';

if Bools.LoadPython
    for i=1:length(Kmeans)
        Histograms(i+1).histo1D = Khist1D{i};
        Histograms(i+1).histo2D = Khist2D{i};
        Histograms(i+1).histoL  = KhistL{i};
        %Histograms(i+1).Lbin  = KLbins{i};
        Histograms(i+1).histo1Dsingle = Khist1Dsingle{i};
        Histograms(i+1).histo2DCC = Khist2DCC{i};
        Histograms(i+1).name = Kmeans(i).class;
    end
    try
        for i=1:length(Parameters.merged)
            Histograms(i+length(Kmeans)+1).histo1D = Khist1D{length(Kmeans)+i};
            Histograms(i+length(Kmeans)+1).histo2D = Khist2D{length(Kmeans)+i};
            Histograms(i+length(Kmeans)+1).histoL  = KhistL{length(Kmeans)+i};
            Histograms(i+length(Kmeans)+1).histo1Dsingle = Khist1Dsingle{i};
            Histograms(i+length(Kmeans)+1).histo2DCC = Khist2DCC{length(Kmeans)+i};
            Histograms(i+length(Kmeans)+1).name = ['Merged class ' num2str(i)];
        end
    catch
    end
end