function [G,Files,Fits]= LoadData(Parameters,Bools)

% Parameters
Files=struct();
Fits = struct();
Nfiles = 0;

%% Directory
if ~exist(Parameters.Fpath,'dir')
    disp('Folder not found')
    return
else
    if ~exist([Parameters.Fpath Parameters.filename '_1.dat'],'file') && ~Bools.Load
          disp('Files not found')
        return
    elseif ~exist([Parameters.savepath Parameters.filename '.mat'], 'file') && Bools.Load
        disp('.mat file not found')
        return
    else
        if Bools.Save && ~exist(Parameters.savepath,'dir')
            mkdir(Parameters.savepath);
        end

    end
end

%% Load and make data
if Bools.Load && exist([Parameters.savepath Parameters.filename '.mat'],'file')
    %% Load
    if ~Bools.RedoHisto
        load([Parameters.savepath Parameters.filename '.mat'], '-regexp',...
            '^(?!Parameters$|Bools$|Plots$).');                             % Does not load these variables
        disp(['Loading data file ' Parameters.filename '.mat']);
        Nfiles=Files.Nfiles;
        disp([num2str(Nfiles) ' trace(s) found'])
        motor=Files.motor         ;
        piezo=Files.piezo         ;
    else
        load([Parameters.savepath Parameters.filename '.mat'],...
            'Parameters','G','Bools','Plots','Files','Fits');                              % Only loads the specified variables
        disp(['Loading data file ' Parameters.filename '.mat']);
        Nfiles=Files.Nfiles;
        disp([num2str(Nfiles) ' trace(s) found']);
        disp('Making new histograms');
        motor=Files.motor         ;
        piezo=Files.piezo         ;
    end
elseif Nfiles == 0
    %% Files counting
    if exist([Parameters.Fpath Parameters.filename '_0.dat'],'file')
        counter = 0;
        k = 0;
    else                                                                    % If first file is _1, Nfiles = counter-1
        counter = 1;
        k = 1;	
    end

    while exist([Parameters.Fpath Parameters.filename '_' num2str(counter) '.dat'],'file')
        counter = counter+1;
    end
    Nfiles = counter - k;
    disp([num2str(Nfiles) ' file(s) found'])

    %% Get measurements parameters
    fid = fopen(strcat(Parameters.Fpath,Parameters.filename,'_',num2str(k),'.dat'));
    filecontent = textscan(fid,'%s','delimiter','\n');
    filecontent = filecontent{:};
    startline = find(strncmp('@',filecontent,1));
    settings = filecontent(1:startline(1)-1);
    settings = regexprep(settings,'G0','G_0');
    piezoline = find(strncmp('Breaking speed 2', settings,16));
    motorline = find(strncmp('motor speed', settings,11));
    voltageline = strncmp('set voltage', settings,11);
    fclose(fid);

    if ~isempty(piezoline)
        piezo = 1;
        motor = 0;
        str = char(filecontent(piezoline));
        piezo_speed = sscanf(str,'Breaking speed 2 : %f');                  % in V/s
        speed = piezo_speed*Parameters.Vtodconversion;                      % in m/s
        fprintf('Piezo speed found: %1.2f V/s\n',piezo_speed);
        str = char(filecontent(piezoline+1));
        making_speed = sscanf(str,'Making speed : %f');                     % in V/s
        making_speed = making_speed*Parameters.Vtodconversion;              % in m/s
    elseif ~isempty(motorline)
        motor = 1;
        piezo = 0;
        str = char(filecontent(motorline));
        motor_speed = sscanf(str,'motor speed : %f');                       % in um/s
        speed = motor_speed * 1e-6;                                         % in m/s
        fprintf('Motor speed found: %1.2f um/s\n',motor_speed);
        making_speed = speed;
    else
       disp('File format not recognized (Not a breaking trace)')
    end

    try
        samplingline = strncmp('sampling rate', settings,13);
        str = char(settings(samplingline));
        sampling_rate = sscanf(str,'sampling rate = %f');                   % in Hz
        points_per_nm = sampling_rate/(speed*attenuation*1e9);
        Files.points_per_nm = points_per_nm;
    catch
        disp('error reading sampling rate')
    end

   str = char(settings(voltageline));
   set_voltage = sscanf(str,'set voltage : %f');                            % in V
   if Bools.correct_voltage 
        set_voltage_corrected = set_voltage-.014;                           % Fixing the bias offset
    else
        set_voltage_corrected = set_voltage;                                % Not fixing the bias offset
    end
   fprintf('Set voltage found: %1.3f V\n',set_voltage_corrected);

    %% Creating struct
    disp('Reading data');
    if Bools.Making
        G(Nfiles) = struct('t_breaking',[],'d_breaking',[],'g_breaking',[],...
            't_making',[],'d_making',[],'g_making',[]);
    else
        G(Nfiles) = struct('t_breaking',[],'d_breaking',[],'g_breaking',[]);
    end
    parfor i = 1:Nfiles
        %disp(strcat(num2str(i),'/',num2str(Nfiles))) %we should ger rid of this, it slows down loading only to write a number on the command window
        
        %Reads the whole file
        fid = fopen(strcat(Parameters.Fpath,Parameters.filename,'_',num2str(i-1+k),'.dat'));
        filecontent = textscan(fid,'%s','delimiter','\n');
        filecontent = filecontent{:};
        startline = find(strncmp('@',filecontent,1));   %REMEMBER there are two @, one for breaking one for making
        fclose(fid);
        tmp=regexp(filecontent(startline(1)+1),'\s*([\S]*)\s*');
        cols = numel(tmp{1});

        % Import breaking trace
        fid = fopen(strcat(Parameters.Fpath,Parameters.filename,'_',num2str(i-1+k),'.dat'));
        if cols == 2
            data = textscan(fid,'%f %f','HeaderLines',startline(1)+1);
        else
            data = textscan(fid,'%f %f %f','HeaderLines',startline(1)+1);
        end
        fclose(fid);

        % Creates struct for breaking data
        G(i).t_breaking = data{1};
        G(i).d_breaking = G(i).t_breaking*speed*Parameters.attenuation*1e9;
        G(i).g_breaking = data{2} * set_voltage / (set_voltage_corrected);

        % Offset correction
        if Bools.Offset
            offset = mean(G(i).g_breaking(end-100:end-50));
            if Bools.Purge && offset > Parameters.Purge_limit
                G(i).g_breaking(:) = Parameters.noiselvl;   
            else
                G(i).g_breaking = G(i).g_breaking-offset;
                G(i).g_breaking(G(i).g_breaking<Parameters.noiselvl) = Parameters.noiselvl;
            end
        else
           G(i).g_breaking = abs(G(i).g_breaking);
        end

        if Bools.Making
            % Import making trace
            fid = fopen(strcat(Parameters.Fpath,Parameters.filename,'_',num2str(i-1+k),'.dat'));
            data = textscan(fid,'%f %f','HeaderLines',startline(2)+1);
            fclose(fid);

            % Creates struct for making data 
            G(i).t_making = data{1};
            G(i).d_making = G(i).t_making*making_speed*Parameters.attenuation*1e9;
            G(i).g_making = data{2} * set_voltage / (set_voltage_corrected);

            % Offset correction
            if Bools.Offset
                G(i).g_making = G(i).g_making-offset;
                G(i).g_making(G(i).g_making<Parameters.noiselvl) = Parameters.noiselvl;
                G(i).g_making = real(log10(abs(G(i).g_making)));
            end
        end
    end
end
%% Restricted range
if Bools.Restricted
    plotstart = Parameters.RestrictedRange(1);
    plotend = Parameters.RestrictedRange(2);
    Nplotted = plotend-plotstart+1;
else
    plotstart = 1;
    plotend = Nfiles;
    Nplotted = Nfiles;
end

%% Outputs
Files.plotstart     = plotstart;
Files.plotend       = plotend;
Files.Nplotted      = Nplotted;
Files.Nfiles        = Nfiles;
Files.motor         = motor;
Files.piezo         = piezo;

end