function Optimize_Binning(G,Parameters,Files)
% This program will make a series of 2D histograms with data already stored in the
% workspace. Each plot will use a different Dbin so that the one without
% aliasing can be selected to be used.

if nargin<1
	G = evalin('base','G');
end
if nargin<2
	Parameters = evalin('base','Parameters');
end
if nargin<3
	Files = evalin('base','Files');
end
Parameters.Dmin = evalin('base','Parameters.Dmin');
Parameters.Dmax = evalin('base','Parameters.Dmax');
Parameters.Gmin = evalin('base','Parameters.Gmin');
Parameters.Gmax = evalin('base','Parameters.Gmax');
Xmin = min(Parameters.xedges);
Xmax = max(Parameters.xedges);
Xbin = numel(Parameters.xedges);
Ymin = log10(min(Parameters.yedges));
Ymax = log10(max(Parameters.yedges));
Nplotted=Files.plotend-Files.plotstart+1;

ZeroDisp = 3e-1;
for i = 1:Files.Nfiles
  try
    ind = find(G(i).g_breaking>ZeroDisp,1,'last');
    d0 = G(i).d_breaking(max(ind));
    G(i).d_breaking = G(i).d_breaking-d0;
  catch
      disp([num2str(i) ' - error finding first point'])
  end
end

D_breaking=vertcat(G(Files.plotstart:Files.plotend).d_breaking);
G_breaking=vertcat(G(Files.plotstart:Files.plotend).g_breaking);

f=figure('KeyPressFcn',@ReadKey,'Name','Dbin Optimization','PaperPosition',[0.6 5 16 20]);
reeval();


   function reeval()
      %fprintf('Dbin = %i\nbinsperG = %i\n',Dbin,binsperG);
      Parameters.xedges = linspace(Xmin,Xmax,Xbin);
      Gbin = round((Ymax-Ymin)*Parameters.binsperY);
      Parameters.yedges = 10.^linspace(Ymin,Ymax,Gbin);

   %	disp(['Histograms include traces from ' num2str(Files.plotstart) ' to ' num2str(Files.plotend)])
      hist2D_bin = hist2(D_breaking,G_breaking, Parameters.xedges, Parameters.yedges);
      hist2D_bin = hist2D_bin/Nplotted;
      hist1D_bin = sum(hist2D_bin,2);

      h1=subplot(2,2,[2 4]);
      plot_2D(hist2D_bin,[],Parameters.Dmin,Parameters.Dmax,Parameters.Gmin,Parameters.Gmax,Parameters.xedges,Parameters.yedges);
      title(sprintf('Dbin = %i; binsperD = %1.2f',Xbin,Xbin/(Xmax-Xmin)));
      set(gca,'Xlim',[Parameters.Dmin Parameters.Dmax])
      set(gca,'Ylim',[Parameters.Gmin Parameters.Gmax])

      h2=subplot(2,2,1);
      tmp = struct();
      tmp.line = 0;
      tmp.result = 0;
      tmp2 = h2.Position;
      plot_1D(hist1D_bin,tmp,Parameters)
      title(sprintf('binsperG = %i',Parameters.binsperY),'fontweight','normal');
      set(gca,'Position',tmp2);

      h3=subplot(2,2,3);
      semilogx(Parameters.yedges(2:end),diff(hist1D_bin));
      pos2 = find(min(abs(Parameters.yedges - 0.3)) == abs(Parameters.yedges - 0.3));
      pos1 = find(min(abs(Parameters.yedges - 5e-6)) == abs(Parameters.yedges - 5e-6));
      MAX = max(abs(diff(hist1D_bin(pos1:pos2))));
      rms = sum(diff(hist1D_bin(pos1:pos2)).^2);
      set(gca,'Xlim',[10^Ymin  3])
      set(gca,'Ylim',[-1.05*MAX 1.05*MAX])
      set(gca,'XTick',10.^linspace(Ymin,Ymax,Ymax-Ymin+1))
      set(gcf,'Position',[250 100 1400 850])
      title(sprintf('diff(1Dhisto)\nrms = %1.3f',rms),'fontweight','normal');

      refreshdata(f);

      end


   function ReadKey(~,evnt)
      KEY=upper(evnt.Key);
      %modifiers=upper(evnt.Modifier);
      modifiers = upper(get(gcf,'currentModifier'));
      CtrlIsPressed = ismember('CONTROL',modifiers);
		ShiftIsPressed = ismember('SHIFT',modifiers);
      
      switch KEY
         case 'RIGHTARROW'
            if CtrlIsPressed
               Xbin=Xbin+1;
				elseif ShiftIsPressed
               Xbin=Xbin+10;
            else
               Xbin=Xbin+5;
            end
            reeval();
            
         case 'LEFTARROW'
				if CtrlIsPressed
               Xbin=Xbin-1;
				elseif ShiftIsPressed
               Xbin=Xbin-10;
            else
               Xbin=Xbin-5;
            end
            reeval();
            
         case 'UPARROW'
				if CtrlIsPressed
               Parameters.binsperY=Parameters.binsperY+1;
				elseif ShiftIsPressed
               Parameters.binsperY=Parameters.binsperY+10;
            else
               Parameters.binsperY=Parameters.binsperY+5;
            end
            reeval();
            
         case 'DOWNARROW'
            if CtrlIsPressed
               Parameters.binsperY=Parameters.binsperY-1;
				elseif ShiftIsPressed
               Parameters.binsperY=Parameters.binsperY-10;
            else
               Parameters.binsperY=Parameters.binsperY-5;
            end
            reeval();

         case 'Q'
            close(f);
            %clear('D_breaking','G_breaking','hist2D_bin');
      end
   end
end