function H = Plot_histograms(Histograms,Parameters,Fits,L_fits,Plots,cmap)
H = cell(1,length(Histograms)*2);

%% 2D histograms
if Plots.Hist2D
    for i=1:length(Histograms)
        H{i} = figure('Position',[500 150 600 750],'PaperPosition',[0.6 5 16 20]);
        plot_2D(Histograms(i).histo2D,[],Parameters.Dmin,Parameters.Dmax,Parameters.Gmin,Parameters.Gmax,Parameters.xedges,Parameters.yedges);
        colormap(gca,cmap)
        colorbar ('Ticks',[])
        set(findall(gcf,'type','text'),'fontsize',20,'fontweight','normal')
        set(findall(gcf,'type','axes'),'fontsize',20,'fontweight','normal')
        f = gcf;
        oldunits = get(f,'Units');
        set(f, 'PaperUnits', 'centimeters', 'Units', 'centimeters');
        figpos = get(f, 'Position');
        f.PaperPositionMode = 'auto';
        set(gcf, 'PaperSize', figpos(3:4), 'Units', oldunits);
    end
end

%% 1D histograms
if Plots.Hist1D
    if length(Histograms)==length(Fits)
        for i=1:length(Histograms)
            H{i+length(Histograms)} = figure('Position',[300 150 1100 775],'PaperPositionMode','auto');
            plot_1D(Histograms(i).histo1D,Fits(i),Parameters)
            f = gcf;
            oldunits = get(f,'Units');
            set(f, 'PaperUnits', 'centimeters', 'Units', 'centimeters');
            figpos = get(f, 'Position');
            f.PaperPositionMode = 'auto';
            set(gcf, 'PaperSize', figpos(3:4), 'Units', oldunits);
        end
    else
        disp('Fits number does not equal histogram number: plotting without fits');
        for i=1:length(Histograms)
            H{i+length(Histograms)} = figure('Position',[300 150 1100 775],'PaperPositionMode','auto');
            plot_1D(Histograms(i).histo1D,Fits(1),Parameters)
            f = gcf;
            oldunits = get(f,'Units');
            set(f, 'PaperUnits', 'centimeters', 'Units', 'centimeters');
            figpos = get(f, 'Position');
            f.PaperPositionMode = 'auto';
            set(gcf, 'PaperSize', figpos(3:4), 'Units', oldunits);
        end
    end
end

%% Summary figures
if Plots.Overview
    for i=1:length(Histograms)
        H{i+2*length(Histograms)} = figure('Position',[500 150 1000 750],'PaperPosition',[0.6 5 16 20]);
        h1=subplot(1,2,1);
        plot_2D(Histograms(i).histo2D,'coupled',Parameters.Dmin,Parameters.Dmax,Parameters.Gmin,Parameters.Gmax,Parameters.xedges,Parameters.yedges);
        colormap(gca,cmap)
        h2=subplot(1,2,2);
        plot_1D(Histograms(i).histo1D,Fits(i),Parameters)
        hor2ver_1Dfit()
        set(gca,'xticklabel',[])
        set(gca,'yticklabel',[])
        ylabel('Counts [a.u.]')
        xlabel([])
        set(findall(gcf,'type','text'),'fontsize',20,'fontweight','normal')
        set(findall(gcf,'type','axes'),'fontsize',20,'fontweight','normal')
        set(h1,'Position',[0.13 0.11 0.37466 0.815])
        set(h2,'Position',[0.5425 0.11 0.37466 0.815])
        f = gcf;
        oldunits = get(f,'Units');
        set(f, 'PaperUnits', 'centimeters', 'Units', 'centimeters');
        figpos = get(f, 'Position');
        f.PaperPositionMode = 'auto';
        set(gcf, 'PaperSize', figpos(3:4), 'Units', oldunits);
    end
end

%% Length histograms
if Plots.HistL
        col = linspecer(10);
        for i=1:length(Histograms)
            H{i+3*length(Histograms)} = figure('Position',[300 150 1100 775],'PaperPositionMode','auto');
            box on
            %bar(Parameters.Ledges,Histograms(i).histoL,'FaceColor',col(3,:))
            plot_L(Histograms(i).histoL,L_fits(i),Parameters, col(3,:))
            set(gca,'linewidth',2);
            set(findall(gcf,'type','text'),'fontsize',24,'fontweight','normal')
            set(findall(gcf,'type','axes'),'fontsize',24,'fontweight','normal')
            f = gcf;
            oldunits = get(f,'Units');
            set(f, 'PaperUnits', 'centimeters', 'Units', 'centimeters');
            figpos = get(f, 'Position');
            f.PaperPositionMode = 'auto';
            set(gcf, 'PaperSize', figpos(3:4), 'Units', oldunits);
            xlabel('Trace length [nm]')
            ylabel('Counts [a.u.]')
        end

end

%% Cross-correlation 2D histogram
if Plots.Hist2DCC
    for i=1:length(Histograms)
        H{i+4*length(Histograms)} = figure('Position',[300 150 1100 775],'PaperPositionMode','auto');
        surf(log10(Parameters.yedges),log10(Parameters.yedges),Histograms(i).histo2DCC,'edgecolor','interp');
        view([0 90])
        colormap(gca,cmap)
        caxis([-1 1])
        colorbar
        set(gca,'linewidth',2);
        set(findall(gcf,'type','text'),'fontsize',24,'fontweight','normal')
        set(findall(gcf,'type','axes'),'fontsize',24,'fontweight','normal')
        f = gcf;
        oldunits = get(f,'Units');
        set(f, 'PaperUnits', 'centimeters', 'Units', 'centimeters');
        figpos = get(f, 'Position');
        f.PaperPositionMode = 'auto';
        set(gcf, 'PaperSize', figpos(3:4), 'Units', oldunits);
        xlabel('Conductance [log(G/G_0)]')
        ylabel('Conductance [log(G/G_0)]')
        xlim([log10(Parameters.Gmin),log10(Parameters.Gmax)]);
        ylim([log10(Parameters.Gmin),log10(Parameters.Gmax)]);
        box on
        set(gca,'XTick',[-6 -5 -4 -3 -2 -1 0 1])
        set(gca,'YTick',[-6 -5 -4 -3 -2 -1 0 1])
        set(gca,'Tickdir','in','Layer','top','XGrid','off','YGrid','off')
    end
end
    