%% Proccessing script for MCBJ data, using K-Means v4
% Alfredo Rates based on plot_histo.m (collective creation)
% alfredo.rates@ug.uchile.cl
% September 2019
% 

%% User interface

%IMPORTANT: To Optimize binning, call this function:
% Optimize_Binning(G,Parameters,Files)
%After optimizing the binning you can skip the loading section but you have
%to re-run the HistoFunction section.

% Reset workspace and command window
close all
clear
clc
addpath(genpath('Functions/'))

% Files info
Parameters=struct();
Parameters.Fpath = ... %Files path
    'D:\Luca\Analysis\Data\OPE2 and DOPE2\OPE2\Sample 1\molecule\16-20\';
Parameters.KPath = ... %Kmeans path, main folder where the matlab/ and KMeans/ folders are
    'D:\Luca\Analysis\Data\OPE2 and DOPE2\OPE2\Sample 1\molecule\16-20\Clustering zoomed 3\scan200124_22\';
Parameters.filename = 'scan200124_22';

% Parameters
Parameters.attenuation =            8e-05;    % calibration between vertical and horizontal displacement
Parameters.binsperX =               66.00;   %75.71; 81.71 50.29 44.29 68.86 58.86  % Binning for 2D histogram plot
Parameters.binsperY =           	33;      	% Binning for 1D histogram plot
Parameters.RestrictedRange =        [1500 6000];   % In case you will use a restricted range
Parameters.Purge_limit =            2e-6;       % Traces with an offset higher than this will be removed
Parameters.Vtodconversion =         0.3e-6;     % 1000V = 300um
Parameters.noiselvl =               1e-12;      % Minimum conductance value

%Kmeans parameters
Parameters.Subclasses = containers.Map;
Parameters.Nclasses =               4;          %N of classes to load

%if there are no subclasses, comment next line
%Parameters.Subclasses('6') =        3;          %Number of subclasses in class 0. Add every subclass set like this!
%Parameters.Subclasses('2') =        3;
Parameters.Subclasses('1') =         3;

%Merged classes
%To merge classes (even if they are subclasses of different classes) you
%can put here a vector where the first value is the original class where
%the subclass is (if it's not a subclass then the first value is -1) and
%the next values are the number of the subclasses to merge STARTING FROM 0.
%If you have subclasses from different classes to merge, then you use
%another vector following the same rule as mentioned above.

% Parameters.merged{1} = {[2,0,2]};
% Parameters.merged{2} = {[-1,0,1],[2,1]};
%Parameters.merged{1} = {[-1,0,3]};

% Plot parameters
Parameters.Xmin =                   -1; 		% (nm)      used for making histograms
Parameters.Xmax =                  	2.5;       	% (nm)      used for making histograms
Parameters.Ymin =                 	-7;        	% log10(G0) used for making histograms
Parameters.Ymax =                 	3;       	% log10(G0) used for making histograms
Parameters.Dmin =                	-0.5;     	% (nm)      displayed in plots
Parameters.Dmax =                 	2.5;      	% (nm)      displayed in plots
Parameters.Gmin =                 	5e-7;     	% (G0)      displayed in plots
Parameters.Gmax =                 	3;        	% (G0)      displayed in plots
Parameters.Lmax =                   3;          % (nm)      to plot trace length histograms
Parameters.Lbin =                   37;         %           bins for trace length histograms
Parameters.LGup =                   3e-1;       % (G0)      Upper limit used for length calcularion. 1 G0 corresponds to the start of clustering ROI
Parameters.LGlow=                   1e-6;       % (G0)      Lower limit used for length calcularion. 1e-6 G0 corresponds to the end of clustering ROI

% Plot booleans
Plots=struct();
Plots.Overview =            1;          % New overview: 2D histogram + 1D histogram rotated
Plots.Hist1D =              0;          % 1D histo
Plots.Hist2D =              0;          % 2D histo
Plots.HistL =               1;          % Length histogram
Plots.Hist2DCC =            0;          % 2D cross correlation histogram
Plots.G0Length =            0;          % 1G_0 Length
Plots.TunSlope =            0;          % Tunneling slope

% Data processing boolean
Bools=struct();
Bools.LoadPython =          1;          % Load KMeans data
Bools.Fit =                 0;          % Fit 1D and get the information, set to 0 if you want to use fits from loaded data; set to 1 to fit again loaded data
Bools.L_Fit =               0;          % Fit Length histograms
Bools.loadParameters =      0;          % Load parameters from KMeans analysis
Bools.Restricted =          0;          % Plot only a restricted subset of the data
Bools.Load =                0;          % Load a previous workspace, if present?
Bools.RedoHisto =           1;          % If you are loading data you can also redo the histograms
Bools.Purge =               1;          % Remove traces with noise level above Purge_limit?
Bools.Offset =              1;          % Offset correction of the data
Bools.Making =              1;          % Load Making Data?
Bools.correct_voltage =     0;          % Does the bias have an offset that needs to be corrected?
Bools.Save =                1;          % Save plots?
Bools.vectorFigures =       0;          % Save figures in vector format?
Bools.Close =               0;          % Close all plots after saving them

%% Load data

% Path name correction and generating savepath variable
Parameters.Fpath = strrep(Parameters.Fpath,'\','/');
Parameters.KPath = strrep(Parameters.KPath,'\','/');
Parameters.savepath = [Parameters.Fpath Parameters.filename '/tmp/'];

%Loads custom colormap used for 2D histo
load('color1.mat')
% Load data
[G,Files,Fits] = LoadData(Parameters,Bools);

% Load Kmeans data
if Bools.LoadPython
    [Kmeans,~]= LoadKmeansData(Parameters,Bools);
else
    Kmeans = false;
end

%% Histogram generation

[G,Histograms,Kmeans,Parameters] = HistoFunction(G,Kmeans,Parameters,Files,Bools);


%% 1G0 length and Tunneling slope

%1G0 fitting
if Plots.G0Length
    Fig_1G0 = Fit_1G0(G,Parameters,Histograms,Files);
end

%Tunneling fitting
if Plots.TunSlope
    Fig_Tunn = Fit_Tunn(G);
end

% Check codes and optimize fittings!
% Make nice fitting plots (keep track of the name of the figure variable!)

% Maybe tunn cali can get an input of the tunn class to fit
% With both funcitons, display the ideal att factor to get the best result.
%   For now, just disp each one. Then they can have weigth and of course we
%   can try to understand it...

%% Fitting interface
if Bools.Fit 
    figure
    Fits = Histogram_Fit(Histograms,Parameters);
elseif ~Bools.Load                      % if load, it loads the previous results, unless you want to fit again
    Fits = struct('line',{},'result',{}); %initializate an empty fit struct to avoid having multiple functions in case of fitting or not
    for i=1:length(Histograms)    
        Fits(i).line=0;
        Fits(i).result=0;
    end
end

if Bools.L_Fit
    L_Fits = Histogram_Fit_L(Histograms,Parameters);
elseif ~Bools.Load                      % if load, it loads the previous results, unless you want to fit again
    L_Fits = struct('line',{},'result',{}); %initializate an empty fit struct to avoid having multiple functions in case of fitting or not
    for i=1:length(Histograms)    
        L_Fits(i).line=0;
        L_Fits(i).result=0;
    end
end

%% Parameters calculation
if Bools.Fit
    Plateau_info = Get_Info(G,Kmeans,Histograms,Parameters,Files,Fits,L_Fits);
end
%The parameters are not calculated for the merged classes! I mean, the
%yield and the length...

%% Plots

H = Plot_histograms(Histograms,Parameters,Fits,L_Fits,Plots,cmap);

%% Save

if Bools.Save
    SaveKmeans(Parameters,H,Bools,Plots,Histograms);
end

%% Close

if Bools.Close
    close all
end

%% TO DO

%To fix:
%   -Length and yield for merged classes
%   -1G0 and Slope fitting (algorithm and figures)
%   -Check python script to save the data correctly! <<<<<<<<<<<<<<<<<<----
