%% Plots the trend of noise level as a function of time
%NOTE to properly work this needs to get data that was loaded without the
%Bools.Purge option
close all
clear
clc

loadpath = 'C:\Data\OPE2-NO2-SMe\H2O ACN\pH 2\Sample 3\molecule pH2\15-19\scan200529_22\';
filename = 'scan200529_22';

loadpath = strrep(loadpath,'\','/');

load([loadpath filename '.mat'])

close all

%% Parameters used for processing and plot

n_points = 100;     %number of points to average over for calculating noise level, counting from the last point in the trace
Gmin     = 1e-7;    %min conductance displayed in plots
Gmax     = 1e-3;    %max conductance displayed in plots

%% Checks noise level and time at which they are collected

DIR = dir([Parameters.Fpath Parameters.filename '*.dat']);
noise = zeros(1,length(G));

for i=1:length(G)
    noise(i)=mean(G(i).g_breaking(end-n_points:end));
    time(i) = datetime(DIR(i).datenum,'ConvertFrom','datenum');
end

time = sort(time); %Necessary because the order of files retrieved from dir() is sorted such that the files are in order _1 _10 _100 _1000 and not _1 _2 ...
time = time - time(1);
time = minutes(time);

%% Plots result

N = figure('Position',[300 150 1100 775],'PaperPositionMode','auto');

set(gcf,'color','white')

scatter(time,noise)
set(gca,'yscale','log')
ylim([Gmin Gmax])
xlabel('Time [min]')
ylabel('Conductance [G_0]')
set(gca,'box','on','linewidth',2);
set(findall(gcf,'type','text'),'fontsize',24,'fontweight','normal','FontName','Arial')
set(findall(gcf,'type','axes'),'fontsize',24,'fontweight','normal','FontName','Arial')

%% Saves result

SaveFigure(N,[Parameters.savepath 'figures/'],'noise_time')