function randomplots_raw(G,Files,Parameters)
% if nargin<1
% 	if fnBaseExist('Nplotted')	% checks if Nplotted exists in the basic workspace
% 		Files.Nplotted = evalin('base','Nplotted');
% 	else
% 		Files.Nplotted = evalin('base','Nfiles');	% otherwise it sets it equal to Nfiles
% 	end
% 	IsMol = ones(Nplotted,1);
% end
% if nargin<3
% 	if fnBaseExist('Files.plotstart')
% 		Files.plotstart = evalin('base','Files.plotstart');
% 		Files.Files.plotend = evalin('base','Files.Files.plotend');
%     else
%         Nplotted = evalin('base','Nfiles');
% 		Files.plotstart = 1;
% 		Files.plotend = Files.Nplotted;
% 	end
% end

pool = 1:length(G); % Pool of numbers that can be extracted
pool = pool(randperm(length(pool))); %shuffles the pool
counter = 1;

y1 = 1e-3;
y2 = 1e-4;

%Close a previous figure with the same name if it's already present
hObject = findobj('Name','Random traces');
close(hObject);

f0 = figure;
set(f0,'Name','Random traces');	% Names h0
set(f0,'KeyPressFcn',@KeyPress);	% Calls KeyPress whenever a key is pressed when h0 is the active figure
hObject = findobj('Name','Random traces');
handles = guidata(hObject);	% Creates a variables for the handles of hObject
handles.selected = [];	% Initialize variable in the handles
handles.quit = 0;
handles.next = 0;
guidata(hObject,handles)	% Updates handles of hObject

suptit = uipanel('Parent',f0,'BorderType','none'); 
suptit.Position = [0.25 0.97 .52 .06];
suptit.Title = sprintf('Press Q to exit the loop, the arrows to skim through the data set, S to save the traces selected so far\n%i/%i\n',(counter),floor(numel(pool)/10));
suptit.TitlePosition = 'centertop'; 
suptit.FontSize = 12;
suptit.FontWeight = 'bold';

while ~handles.quit
	r = pool(counter:counter+9); % Extract 10 traces from pool
	for iii = 1:numel(r)
		%disp([num2str(iii) ': ' num2str(r(iii))]);
		h(iii)=subplot(2,5,iii);
		%plot_single_trace(G(r(iii)).d_breaking,G(r(iii)).g_breaking,r(iii));
		plot_single_trace_cluster(r(iii),G,Parameters);
		set(h(iii), 'ButtonDownFcn', {@AddToSelected,r(iii)});	% Makes the subplots clickable and passes the number of the trace to AddToSelected
		line(xlim,[y2 y2],'Color','g');
		line(xlim,[y1 y1],'Color','g');
	end
	handles.next = 0;
	guidata(hObject,handles) % Updates handles of hObject (saves the updated handles.selected)
	
	% Pressing an arrow exits the inner while loop and continues the outer
	% one, plotting 10 more traces. Pressing S makes plot of the traces 
   % saved in 'selected'. Pressing Q exits the inner loop and
	% breaks out of the outer loop. Pressing any other key does nothing.

   %fprintf('Press Q to exit the loop, the arrows to skim through the data set, S to save the traces selected so far\n%i/%i',(counter),floor(numel(pool)/10));
	while ~handles.next
		pause(0.001);
		hObject = findobj('Name','Random traces');
		handles = guidata(hObject);
		selected = handles.selected;
		selected = sort(unique(selected));
	end
end
assignin('base','selected',selected);
close(f0);

	function AddToSelected(src,evnt,trace_number)
		hObject = findobj('Name','Random traces');
		handles = guidata(hObject);
		
		%determine which modifiers have been pressed
		%   if strcmp(evnt.Key,'tab')
		handles.selected = [handles.selected trace_number];
		disp([num2str(trace_number) ' added to selected'])
		X = get(src,'Xlim');
		Y = get(src,'Ylim');
		patch(X([1 2 2 1]),Y([1 1 2 2]),[0.5 0.5 0.5],'FaceAlpha',0.6,'parent', src);
		%unactive=patch('Faces',f,'Vertices',v,'EdgeColor','none','FaceColor',[0.5 0.5 0.5],'FaceAlpha',.6);
		
		%   end
		
		guidata(hObject,handles)
	end

	function KeyPress(src,evnt)
		
		hObject = findobj('Name','Random traces');
		handles = guidata(hObject);
		
		KEY=upper(evnt.Key);
		%determine which modifiers have been pressed
		if strcmp(KEY,'Q')
			handles.next = 1;
			handles.quit = 1;
		end
		
      if any(ismember({'DOWNARROW' 'RIGHTARROW'},KEY))
         counter=counter+10;
         if counter >= numel(pool)
            counter = numel(pool);
            suptit.Title = 'Upper limit reached';
         else
            suptit.Title = sprintf('Press Q to exit the loop, the arrows to skim through the data set, S to save the traces selected so far\n%i/%i',(counter),floor(numel(pool)/10));
         end
         handles.next = 1;
      end
      
      if any(ismember({'UPARROW' 'LEFTARROW'},KEY))
         counter=counter-10;
         if counter <= 0
            counter = 1;
            suptit.Title = 'Lower limit reached';
         else
            suptit.Title = sprintf('Press Q to exit the loop, the arrows to skim through the data set, S to save the traces selected so far\n%i/%i',(counter),floor(numel(pool)/10));
         end
         handles.next = 1;
      end

		if strcmp(KEY,'S')
			disp(['Saving traces: ' sprintf('%i\n',selected)])
			print_single_traces_cluster(selected,G,Parameters)
         assignin('base','selected',selected);
		end

		guidata(hObject,handles)
		
	end
end

function plot_single_trace_cluster(trace_number,G,Parameters)

	Dmin = Parameters.Dmin;
	Dmax = Parameters.Dmax;
	Gmin = Parameters.Gmin;
	Gmax = Parameters.Gmax;

	%semilogy(G(trace_number).d_breaking,G(trace_number).g_breaking,'.');
   semilogy(G(trace_number).d_breaking,G(trace_number).g_breaking);
   title(['Trace ' num2str(trace_number)])
   xlabel('Electrodes displacement [nm]');
   ylabel('Conductance [G_0]');
	%set(gca,'Xlim',[-0.5 3.5])
	set(gca,'Xlim',[Dmin Dmax])
   %set(gca,'Xlim',[min(Parameters.xedges) max(Parameters.xedges)])
   set(gca,'Ylim',[Gmin Gmax])
   set(gcf, 'Position', [200 75 1500 900])
end

function print_single_traces_cluster(selected,G,Parameters)

	savepath = Parameters.Fpath;
	filename = Parameters.filename;
	Save = 1;
	Close = 0;

	f = figure('NumberTitle','off','PaperPosition',[0.6 5 16 20]); %'NumberTitle','off' is used to remove the "Figure X" text
    for i = 1:numel(selected)
      set(f,'name',['Trace ' num2str(selected(i))])
		subplot('position',[0.17 0.15 0.7 0.8])
		% set(gcf,'PaperPositionMode','auto')	% Forces the figure's size and location on the printed page to directly reflect the figure's size on the screen
		semilogy(G(selected(i)).d_breaking,G(selected(i)).g_breaking,'Linewidth',2.0);
		set(gca,'Xlim',[-0.3 3.5]);
		set(gca,'Ylim',[1e-7 3]);
%		set(gca,'Ylim',[5e-7 2e-4]);
		set(gca,'YTick',[1e-8 1e-7 1e-6 1e-5 1e-4 1e-3 1e-2 1e-1 1]);
		set(gca,'Tickdir','in');
		ylabel('Conductance [G_0]');
		xlabel('Electrode displacement [nm]');
		set(gcf,'Position',[500 150 600 750]);
		set(gca,'Linewidth',2)
		set(gca,'fontsize',20,'fontweight','normal')

		if Save == 1
			if ~exist([savepath 'selected traces/raw/'],'dir')
				mkdir([savepath 'selected traces/raw/']);
			end
			
			saveas(f,[savepath 'selected traces/raw/' filename '_trace' num2str(selected(i)) '.png'])
%			saveas(f,[savepath 'selected traces/' filename '_trace' num2str(selected(i)) '.fig'])

%			saveas(f,[savepath 'selected traces/' filename '_trace' num2str(selected(i)) '.eps'],'psc2')
		else
			disp ('Traces not saved');
        end
    end
   
   if Close
      close(f)
   end
end